import java.util.*;
public class product {
	
	static HashMap<Long,Integer> pRepMemo;
	static int[] upperbound;
	static HashMap<Long,Long>[][] memo;
	static int v;
	
	/*
	 
	  	There is a subproblem in which you must compute the pRepeat value for a certain number.
	 	You can prove that the number gets smaller after each iteration. Eventually it becomes a single digit
	 	after log n steps. I memoize this function since it will be called many times in my solution.
	 
	 	This problem is done with a digit descent dp in which your state
	 	includes the product of all the numbers you placed so far in addition to
	 	the digit index. You may think that there are too many possible products
	 	since they can range from 0 to 9^13, but most of the numbers are not reachable
	 	as products. This includes any number with a prime factor larger than 10.
	 	An upperbound on the number of possible products can be calculated by considering
	 	the maximum powers for all the primes less than 10. The maximum power of 2 is
	 	39 (from the number with 13 8's). For 3 it is 26 (the number with 13 9's) and for
	 	5 and 7 it is 13. Multiplying the number of possible powers for each prime together
	 	yields 211,680 which is enough to make the dp run in time (The actual number is
	 	smaller than this). However, the memo needs to only store products that are reachable
	 	(we can not make an array of size 9^13). I used HashMaps to handle this on the fly.
	 	
	 	There is an alternate solution not using hashmaps that stores powers of all the primes
	 	in the dp state, but I find it to be more clunky.
	 	
	 */
	
	public static void main(String[] args)  {
		
		pRepMemo = new HashMap<Long,Integer>();
		
		Scanner in = new Scanner(System.in);
				
			long a = in.nextLong();
			long b = in.nextLong();
			v = in.nextInt();
			
			/*
			 I call the main dp twice.
			 The answer is computed as count from 0 to b minus the count from 0 to a-1
			 */
			setupper(b);
			long ans = dp(0,1,1);
			setupper(a-1);
			ans -= dp(0,1,1);
			
			System.out.println(ans);
		
		in.close();
	}
	
	static void setupper(long u){
		upperbound = new int[Long.toString(u).length()];
		//saving the digits of the upperbound into an array for the dp
		for(int at = 0; at < upperbound.length; at++){
			upperbound[upperbound.length-1-at] = (int)(u%10);
			u /= 10;
		}
		int len = upperbound.length;
		//setting up the memo, which is a 2D array of Hashmaps
		memo = new HashMap[len][4];
		for(int i =0; i < memo.length; i++)
			for(int j =0; j < memo[0].length; j++)
				memo[i][j] = new HashMap<Long,Long>();
		
	}
	/*	dig is the current digit dex, and pro is the product so far
		matchnzero is a combination of two flags:
		First I need to know if the number I've built so far is matching the upperbound.
		If it is, I need to be careful to not place a digit so it exceeds the upperbound.
		Second, I need to know if placing a zero results in a leading zero or an actual zero.
		You could split these variables, but your memo array gains a dimension
		
	*/
	static long dp(int dig, int matchnzero, long pro){
		if(dig == memo.length){
			int save = pRep(pro);
			if(save == v){ //we hit the target value
				return 1;
			}
			else return 0;
		}
		
		int match = (matchnzero &1);
		int placednonzero = ((matchnzero>>1)&1);
		
		if(memo[dig][matchnzero].containsKey(pro)) return memo[dig][matchnzero].get(pro);
		
		
		long ret = 0;
		//try placing all digits and sum up all the counts from each
		for(int place = 0; place < 10; place++){
			if(match == 1 && place > upperbound[dig]) continue;
			
			long npro = pro;
			
			if(place == 0){
				if(placednonzero == 1){
					npro = 0;
				}
			}
			else npro *= place;
			
			int nextplacednonzero = placednonzero;
			if(place > 0) nextplacednonzero = 1;
			
			int nextmatch = match;
			if(place < upperbound[dig]) nextmatch = 0;
			
			long save = dp(dig+1,nextmatch+(nextplacednonzero<<1),npro);

			
			ret += save;
			
		}
		
		memo[dig][matchnzero].put(pro, ret);
		return ret;
	}
	
	static int pRep(long pro){
		long cur = pro;
		if(!pRepMemo.containsKey(pro)){
			while(cur >= 10){
				long next = 1;
				while(cur > 0){
					next *= cur%10;
					cur /= 10;
				}
				cur = next;
			}
			pRepMemo.put(pro, (int)(cur));
		}
		return pRepMemo.get(pro);
	}
	
	
	

}